@echo off
setlocal

:: Create roadmap_monetary_policy_models.rst
echo Monetary Policy Models > roadmap_monetary_policy_models.rst
echo ======================= >> roadmap_monetary_policy_models.rst
echo. >> roadmap_monetary_policy_models.rst
echo This section includes planned models for monetary policy. Contributions are welcome! >> roadmap_monetary_policy_models.rst
echo. >> roadmap_monetary_policy_models.rst
echo - Taylor Rule >> roadmap_monetary_policy_models.rst
echo - Balanced Approach Rule >> roadmap_monetary_policy_models.rst
echo - First Difference Rule >> roadmap_monetary_policy_models.rst
echo - McCallum Rule >> roadmap_monetary_policy_models.rst
echo - Orphanides Rule >> roadmap_monetary_policy_models.rst
echo - Friedman Rule >> roadmap_monetary_policy_models.rst
echo - Interest Rate Smoothing Models >> roadmap_monetary_policy_models.rst

:: Create roadmap_quantity_of_money_theory.rst
echo Quantity of Money Theory > roadmap_quantity_of_money_theory.rst
echo ======================== >> roadmap_quantity_of_money_theory.rst
echo. >> roadmap_quantity_of_money_theory.rst
echo This section includes planned models related to the Quantity of Money Theory. Contributions are welcome! >> roadmap_quantity_of_money_theory.rst
echo. >> roadmap_quantity_of_money_theory.rst
echo - Fisher Equation >> roadmap_quantity_of_money_theory.rst
echo - Cambridge Equation >> roadmap_quantity_of_money_theory.rst
echo - Velocity of Money Models >> roadmap_quantity_of_money_theory.rst
echo - Quantity Theory of Money (QTM) >> roadmap_quantity_of_money_theory.rst
echo - Money Demand Function (Md) >> roadmap_quantity_of_money_theory.rst

:: Create roadmap_exchange_rate_models.rst
echo Economic Models to Predict Future Exchange Rates > roadmap_exchange_rate_models.rst
echo ================================================ >> roadmap_exchange_rate_models.rst
echo. >> roadmap_exchange_rate_models.rst
echo This section includes planned models for predicting future exchange rates. Contributions are welcome! >> roadmap_exchange_rate_models.rst
echo. >> roadmap_exchange_rate_models.rst
echo - Purchasing Power Parity (PPP) >> roadmap_exchange_rate_models.rst
echo - Interest Rate Parity (IRP) >> roadmap_exchange_rate_models.rst
echo - Monetary Models of Exchange Rates >> roadmap_exchange_rate_models.rst
echo - Portfolio Balance Models >> roadmap_exchange_rate_models.rst
echo - Behavioral Equilibrium Exchange Rate (BEER) >> roadmap_exchange_rate_models.rst
echo - Fundamental Equilibrium Exchange Rate (FEER) >> roadmap_exchange_rate_models.rst

:: Create roadmap_macroeconomic_models.rst
echo Macroeconomic Models > roadmap_macroeconomic_models.rst
echo ===================== >> roadmap_macroeconomic_models.rst
echo. >> roadmap_macroeconomic_models.rst
echo This section includes planned macroeconomic models. Contributions are welcome! >> roadmap_macroeconomic_models.rst
echo. >> roadmap_macroeconomic_models.rst
echo - IS-LM Model >> roadmap_macroeconomic_models.rst
echo - AD-AS Model >> roadmap_macroeconomic_models.rst
echo - Solow Growth Model >> roadmap_macroeconomic_models.rst
echo - New Keynesian Models >> roadmap_macroeconomic_models.rst
echo - RBC (Real Business Cycle) Model >> roadmap_macroeconomic_models.rst
echo - DSGE (Dynamic Stochastic General Equilibrium) Models >> roadmap_macroeconomic_models.rst

:: Create roadmap_microeconomic_models.rst
echo Microeconomic Models > roadmap_microeconomic_models.rst
echo ===================== >> roadmap_microeconomic_models.rst
echo. >> roadmap_microeconomic_models.rst
echo This section includes planned microeconomic models. Contributions are welcome! >> roadmap_microeconomic_models.rst
echo. >> roadmap_microeconomic_models.rst
echo - Supply and Demand Models >> roadmap_microeconomic_models.rst
echo - Consumer Choice Theory >> roadmap_microeconomic_models.rst
echo - Production Theory >> roadmap_microeconomic_models.rst
echo - Cost Functions >> roadmap_microeconomic_models.rst
echo - Game Theory Models >> roadmap_microeconomic_models.rst
echo - Market Structure Models (Perfect Competition, Monopoly, Oligopoly) >> roadmap_microeconomic_models.rst

:: Create roadmap_discounted_cash_flow_models.rst
echo Discounted Cash Flow Models > roadmap_discounted_cash_flow_models.rst
echo ============================ >> roadmap_discounted_cash_flow_models.rst
echo. >> roadmap_discounted_cash_flow_models.rst
echo This section includes planned models for discounted cash flow analysis. Contributions are welcome! >> roadmap_discounted_cash_flow_models.rst
echo. >> roadmap_discounted_cash_flow_models.rst
echo - Dividend Discount Model (DDM) >> roadmap_discounted_cash_flow_models.rst
echo - Free Cash Flow to Equity (FCFE) >> roadmap_discounted_cash_flow_models.rst
echo - Free Cash Flow to Firm (FCFF) >> roadmap_discounted_cash_flow_models.rst
echo - Net Present Value (NPV) >> roadmap_discounted_cash_flow_models.rst
echo - Internal Rate of Return (IRR) >> roadmap_discounted_cash_flow_models.rst
echo - Adjusted Present Value (APV) >> roadmap_discounted_cash_flow_models.rst

:: Create roadmap_financial_models.rst
echo Financial Models > roadmap_financial_models.rst
echo ================ >> roadmap_financial_models.rst
echo. >> roadmap_financial_models.rst
echo This section includes planned financial models. Contributions are welcome! >> roadmap_financial_models.rst
echo. >> roadmap_financial_models.rst
echo - Capital Asset Pricing Model (CAPM) >> roadmap_financial_models.rst
echo - Arbitrage Pricing Theory (APT) >> roadmap_financial_models.rst
echo - Black-Scholes Option Pricing Model >> roadmap_financial_models.rst
echo - Bond Valuation Models >> roadmap_financial_models.rst
echo - Credit Risk Models (e.g., Merton Model) >> roadmap_financial_models.rst
echo - Portfolio Optimization Models (e.g., Markowitz Model) >> roadmap_financial_models.rst

:: Create roadmap_fiscal_policy_models.rst
echo Fiscal Policy Models > roadmap_fiscal_policy_models.rst
echo ===================== >> roadmap_fiscal_policy_models.rst
echo. >> roadmap_fiscal_policy_models.rst
echo This section includes planned models for fiscal policy analysis. Contributions are welcome! >> roadmap_fiscal_policy_models.rst
echo. >> roadmap_fiscal_policy_models.rst
echo - Taxation and Government Spending Models >> roadmap_fiscal_policy_models.rst
echo - Budget Deficit Models >> roadmap_fiscal_policy_models.rst
echo - Public Debt Models >> roadmap_fiscal_policy_models.rst
echo - Fiscal Multiplier Models >> roadmap_fiscal_policy_models.rst
echo - Laffer Curve >> roadmap_fiscal_policy_models.rst
echo - Ricardian Equivalence >> roadmap_fiscal_policy_models.rst

:: Create roadmap_other_economic_models.rst
echo Other Well-Known Economic Models > roadmap_other_economic_models.rst
echo ================================ >> roadmap_other_economic_models.rst
echo. >> roadmap_other_economic_models.rst
echo This section includes other planned economic models. Contributions are welcome! >> roadmap_other_economic_models.rst
echo. >> roadmap_other_economic_models.rst
echo - Behavioral Economics Models >> roadmap_other_economic_models.rst
echo - Agent-Based Models >> roadmap_other_economic_models.rst
echo - Environmental Economics Models >> roadmap_other_economic_models.rst
echo - International Trade Models (e.g., Heckscher-Ohlin Model) >> roadmap_other_economic_models.rst
echo - Labor Market Models >> roadmap_other_economic_models.rst
echo - Health Economics Models >> roadmap_other_economic_models.rst

endlocal
